/*
 *	aegis - project change supervisor
 *	Copyright (C) 1992-1994, 1997, 2003 Peter Miller;
 *	All rights reserved.
 *
 *	This program is free software; you can redistribute it and/or modify
 *	it under the terms of the GNU General Public License as published by
 *	the Free Software Foundation; either version 2 of the License, or
 *	(at your option) any later version.
 *
 *	This program is distributed in the hope that it will be useful,
 *	but WITHOUT ANY WARRANTY; without even the implied warranty of
 *	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *	GNU General Public License for more details.
 *
 *	You should have received a copy of the GNU General Public License
 *	along with this program; if not, write to the Free Software
 *	Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.
 *
 * MANIFEST: interface definition for common/getdate.y
 */

#ifndef COMMON_GETTIME_H
#define COMMON_GETTIME_H

/** \addtogroup Date
  * \brief Date and time manipulation
  * \ingroup Common
  * @{
  */

#include <ac/time.h>
#include <main.h>

time_t date_scan(const char *);
const char *date_string(time_t);

/** @} */
#endif /* COMMON_GETTIME_H */
